#!/bin/sh
# $Id: release.sh 203 2011-01-26 03:15:23Z tjn $

die()
{
 	local retval=$1
	local msg=$2

	echo "$msg"
	exit $retval
}

C3_SVN_TAG=`./dist/get-version.sh  ./VERSION --svn-tag`
C3_MAJOR_VER=`./dist/get-version.sh ./VERSION --major`
C3_MINOR_VER=`./dist/get-version.sh ./VERSION --minor`
C3_RELEASE_VER=`./dist/get-version.sh ./VERSION --release`
C3_XYZ_VERSION="$C3_MAJOR_VER.$C3_MINOR_VER.$C3_RELEASE_VER"


# Prep/configure working dir
./autogen.sh && ./configure || die 1 "Error: autogen or configure problem"

# Generate source tarball
make dist       || die 1 "Error: 'make dist' failed"

# Generate RPM & SRPM package files 
make dist-rpm   || die 1 "Error: 'make dist-rpm' failed"

# Generate Debian package files
DEB_PKG_VER=`./dist/get-deb-package-version.sh ./debian/changelog`
echo "Debian version: $DEB_PKG_VER"
echo "C3 version: $C3_XYZ_VERSION"
if [ "x$DEB_PKG_VER" != "x$C3_XYZ_VERSION" ] ; then
    echo "************************************************"
    echo "ERROR: ./debian/changelog is out-of-date"
    echo "Please use the dch -v ./debian/changelog command"
    echo "************************************************"
    exit 1
fi

#
# TODO: Fix innocuous error about signing of files (see ticket:27)
#
#make dist-deb  || die 1 "Error: 'make dist-deb' failed"
make dist-deb

# Copy debian files to CWD (for consistency)
cp ../c3*$C3_XYZ_VERSION*    ./

# Cleanup working dir
make clean-release
#make distclean clean-scratch


echo "  ******************************************"
echo ""
echo "Release files:"

release_files=`ls -1 c3*$C3_XYZ_VERSION*` 
for file in $release_files ; do
  echo "  $file"
done

echo ""
echo " MD5SUMs:"

for file in $release_files ; do
  md5sum $file
done

echo ""
echo "The SVN tag for this release would be: "
echo "   '$C3_SVN_TAG'"
echo ""
echo ""
echo "  ******************************************"

exit 0
